@@ -4,7 +4,8 @@ use warnings;
 
 sub return_data {
     my $handle = do { no strict 'refs'; \*{"main::DATA"} };
-    return scalar <$handle>;
+    (my $line = <$handle>) =~ s/\r?\n?$//;
+    return $line;
 }
 
 1;
